summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmclippedbyedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmclippedbyedit.h')
-rw-r--r--kpovmodeler/pmclippedbyedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmclippedbyedit.h b/kpovmodeler/pmclippedbyedit.h
index 9050f406..53eef1d8 100644
--- a/kpovmodeler/pmclippedbyedit.h
+++ b/kpovmodeler/pmclippedbyedit.h
@@ -39,9 +39,9 @@ class PMClippedByEdit : public PMDialogEditBase
typedef PMDialogEditBase Base;
public:
/**
* Creates a PMClippedByEdit with tqparent and name
*/
- PMClippedByEdit( TQWidget* tqparent, const char* name = 0 );
+ PMClippedByEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -39,9 +39,9 @@ class PMClippedByEdit : public PMDialogEditBase
public:
/**
- * Creates a PMClippedByEdit with tqparent and name
+ * Creates a PMClippedByEdit with parent and name
*/